package com.tutorialesprogramacionya.compose26

import android.content.Context
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.material.*
import androidx.compose.runtime.*
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.compose.foundation.background
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.verticalScroll
import androidx.compose.ui.Alignment
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.unit.sp
import com.android.volley.Request
import com.android.volley.toolbox.StringRequest
import com.android.volley.toolbox.Volley

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            PantallaPrincipal()
        }
    }
}

@Composable
fun PantallaPrincipal() {
    val contexto = LocalContext.current
    var url by remember { mutableStateOf("https://www.google.com.ar") }
    var pagina by remember { mutableStateOf("") }
    val scroll = rememberScrollState(0)
    Column(
        modifier = Modifier.fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        OutlinedTextField(
            value = url,
            onValueChange = { url = it },
            label = {
                Text(text = "Url del sitio")
            },
            modifier = Modifier
                .fillMaxWidth()
                .padding(5.dp)
        )
        Button(onClick = {
            RecuperarPagina(contexto, url, {
                pagina = it
            })
        }) {
            Text(text = "Recuperar",modifier=Modifier.padding(5.dp))
        }
        Text(
            text = "$pagina",
            fontSize = 15.sp,
            modifier = Modifier
                .verticalScroll(scroll)
                .fillMaxWidth()
                .background(Color(0xFFeeeee4))
                .weight(1f)
        )
    }
}

fun RecuperarPagina(contexto: Context, url: String, datosRecuperados: (String) -> Unit) {
    val queue = Volley.newRequestQueue(contexto)
    val requerimiento = StringRequest(
        Request.Method.GET,
        url,
        { response ->
            datosRecuperados(response.toString())
        }
    ) { error -> }

    queue.add(requerimiento)
}